@@ -7,7 +7,7 @@ from tasq_cli.utils import get_config_directory, get_config_file_path, get_crede
 KB = 1024
 MB = KB * 1024
 
-VERSION = '1.0.36'
+VERSION = '1.0.37'
 
 # ---
 # Logging
@@ -19,7 +19,9 @@ def setup_logger():
     logger.setLevel(logging.DEBUG)
 
     # create file handler
-    fh = logging.handlers.RotatingFileHandler(os.path.join(get_config_directory(), 'cli.log'), maxBytes=10*MB, backupCount=5)
+    fh = logging.handlers.RotatingFileHandler(
+        os.path.join(get_config_directory(), 'cli.log'), maxBytes=10 * MB, backupCount=5
+    )
     fh.setLevel(logging.DEBUG)
 
     # create console handler
@@ -36,6 +38,7 @@ def setup_logger():
 
     return logger
 
+
 _logger = setup_logger()
 
 
@@ -43,33 +46,10 @@ def get_logger():
     return _logger
 
 
-# ---
-# Credentials
-# ---
-
-# this should be init, so it doesn't break preemptively
-
-creds = get_credentials()
-
-if not creds.get('client_id', None) or not creds.get('access_key', None) or not creds.get('secret_key', None):
-    _logger.critical('Credentials not set!')
-    _logger.critical(f'Please add valid credentials to {get_config_file_path()}')
-    exit(1)
-
-CLIENT_ID = creds['client_id']
-BUCKET = creds['bucket_name']
-ACCESS_KEY = creds['access_key']
-SECRET_KEY = creds['secret_key']
-TOKEN = creds['token']
-
-#SERVER = 'http://localhost:8000/api/v2'
 SERVER = 'https://console.tasq.ai/api/v2'
 
 # ---
 # Settings
 # ---
 
-# TODO
-## pip distribution
-
 CDN_URL = 'https://assets.tasq.ai/{object_name}'
